/***************************************************************************
 *   Copyright (C) 2011-2013 by Flukz Team                                 *
 *   Contact : see our web site http://flukz.org/                          *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "highscorefile.h"

#include<QString>
#include<QTextStream>
#include<QFile>
#include<QDateTime>

//load an existing high-score file
void HighScoreFile::loadExistingFile(const QString& localFileName) {
	QFile file(localFileName);
	file.open( QIODevice::ReadOnly );
	QTextStream text( &file );
	text.setCodec("UTF-8");
	
	//read header
	if (!text.atEnd() ) {
		QString headerName("[Flukz HighScore File]");
		if (text.readLine()!=headerName) {
			file.close();
			return;
		}
	}
	
	//read string format version
	int stringFormatVersion=-1;
	if (!text.atEnd() ) {
		QString line = text.readLine();
		stringFormatVersion = line.toInt();
	}
	
	if(stringFormatVersion!=0) {
		//unsupported version
		file.close();
		return;
	}
	
	//read the list of high scores
	QString playerName, timeT, time, date, comment;
	int score;
	while ( !text.atEnd() ) {
		//read one line (=one highscore) 
		text >> score;
		text >> playerName;
		text >> timeT;
		comment = text.readLine();
		
		//insert this score and the associated details in the map that stores all highscores
		ScoreInfo scoreInfo;
		scoreInfo.playerName = playerName;
		scoreInfo.timeT = timeT;
		scoreInfo.comment = comment;
		scoreMap.insert(score, scoreInfo);
		
		//QDateTime dateTime = QDateTime::fromTime_t(timeT.toUInt());
		//time = dateTime.toString("hh:mm");
		//date = dateTime.toString("dd MMMM yyyy");
	}
	
	file.close();
}

//load an existing high-score file
void HighScoreFile::writeFile(const QString& localFileName) {
	QFile file(localFileName);
	if(!file.open( QIODevice::WriteOnly )) return;	//error case
	QTextStream text( &file );
	text.setCodec("UTF-8");
	
	//header
	QString headerName("[Flukz HighScore File]");
	text << headerName << "\n";
	
	//string format version
	int stringFormatVersion=0;
	text << stringFormatVersion << "\n";
	
	//write the list of high scores
	QMap<int, ScoreInfo>::iterator iter;
	
	for(iter=scoreMap.begin(); iter!=scoreMap.end(); iter++) {
		text << iter.key() << " ";
		text << iter.value().playerName << " ";
		text << iter.value().timeT << " ";
		text << iter.value().comment << "\n";
	}
	
	file.close();
}

